#
# spec file for package python-oic
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%global modname oic
Name:           python-oic
Version:        1.2.0
Release:        bp154.1.17
Summary:        A complete OpenID Connect implementation in Python
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/OpenIDC/pyoidc
Source:         https://github.com/OpenIDC/pyoidc/archive/%{version}.tar.gz#/%{modname}-%{version}.tar.gz
BuildRequires:  %{python_module Mako}
BuildRequires:  %{python_module cryptography}
BuildRequires:  %{python_module defusedxml}
BuildRequires:  %{python_module freezegun}
BuildRequires:  %{python_module future}
BuildRequires:  %{python_module ldap}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pyjwkest >= 1.3.6}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module responses}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module testfixtures}
BuildRequires:  %{python_module typing_extensions}
BuildRequires:  %{python_module typing}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-dbm
Requires:       python-Beaker
Requires:       python-Mako
Requires:       python-cryptography
Requires:       python-defusedxml
Requires:       python-future
Requires:       python-pycryptodomex
Requires:       python-pyjwkest >= 1.3.6
Requires:       python-requests
Requires:       python-setuptools
Requires:       python-typing
Requires:       python-typing_extensions
Suggests:       python-ldap
BuildArch:      noarch
%ifpython3
Requires:       python3-dbm
%endif
%python_subpackages

%description
This is a complete Python implementation of OpenID Connect as specified in
the OpenID Connect Core specification. As a side effect, this is a complete
implementation of OAuth2.0 too.

%prep
%setup -q -n pyoidc-%{version}
find src -type f -exec sed -i '1 {/#!/d}' {} +

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PYTHONPATH=src
%pytest -k 'not network'

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitelib}/*
%{_bindir}/oic-client-management

%changelog
* Thu Mar 26 2020 pgajdos@suse.com
- version update to 1.2.0
  [#]# 1.2.0 [2020-02-05]
  [#]## Fixed
  - [#727] OAuth client request using Client Credentials grant
  [#]## Added
  - [#719] Add support for JWT registration tokens
  - [#728] OAuth client request using Extension grant
  - [#731] Session cookie need to be visible to OP IFrame.
  [#]# 1.1.2 [2019-11-23]
  [#]## Fixed
  - [#711] Deal with no post_logout_redirect_uri
  - [#712] Set Content-Type on BackChannel logout POST.
  - [#717] Missing OP logout metadata.
  [#]# 1.1.1 [2019-11-04]
  [#]## Fixed
  - [#708] Wants the original non-parsed JWT and not an IDToken instance.
  [#]# 1.1.0 [2019-10-25]
  [#]## Changed
  - [#688] Second stage of adding logout support.
  - [#700] Third stage of adding logout support, provider side
  [#]## Fixed
  - [#602] Fixed uncaught error on unpacking of message
  - [#679] Make `state` optional in `EndSessionRequest`
  - [#683] Fix basic_auth with client password
  - [#698] `state` in `EndSessionRequest` request args and kwargs different
  [#]## Removed
  - [#671] Removed deprecated request/response_cls kwargs from Provider/Client methods
  - [#677] Removed more deprecated code
* Tue Jul 30 2019 pgajdos@suse.com
- version update to 1.0.1
  [#]## Fixed
  - [#341] Using constant time comparison for password verification
  - [#598] Move alabaster from runtime dependencies to docs
  - [#398] Do not echo cookies that do not belong to us
  - [#607] Fixed key recovery on encryption of payload
  - [#618] Prettified `client_management.py` CLI and wrapped it as
    a setup.py console script `oic-client-management`
  - [#615] Fix ROPC grant in the extensions provider
  - [#640] Use more secure random generator for client_secret
  - [#639] Make sure symmetric keys are available after server restart
  - [#146] Make SessionDB storage conductive with multi-session
  [#]## Changed
  - [#578] Dropped python 2.7 support
  - [#612] Dropped python 3.4 support
  - [#588] Switch to defusedxml for XML parsing
  - [#605] Message.c_param dictionary values have to be a ParamDefinition namedtuple type
  - [#56] Updated README, CLI help texts, pip requirements.txt and such for OP2,
    making it into a stand-alone example easy for beginners to take on
  - [#624] token_endpoint implementation and kwargs have been changed
  - [#629] Duplicated methods in oic.oic classes were removed.
  - [#642] Deprecated `bearer_auth` method.
  - [#631] Refactored message type handling in Client/Provider.
  - [#644] refresh_db kwarg in SessionDB has been deprecated
  [#]## Added
  - [#655] Host can be forced on webfinger discovery
  - [#441] CookieDealer now accepts secure and httponly params
  - [#638] Moved `providerinfo_endpoint` from `oic.extensions` to `oic.oauth2`
  - [#664] Messages needed for Single-Sign-Out Support
  * python3 only package
* Thu Apr 18 2019 Jan Engelhardt <jengelh@inai.de>
- Make it so the description has proper SVO sentences.
* Thu Apr 11 2019 John Vandenberg <jayvdb@gmail.com>
- Activate test suite, using GitHub archive for the tests
- Add missing runtime dependencies
- Use fdupes and fix hashbangs
- Add %%license
- Remove build dependency on devel
* Fri Apr  5 2019 Michael Ströder <michael@stroeder.com>
- updated project URL
- update to 0.15.1
  (way too many changes to be listed here)
* Fri Jul 21 2017 michael@stroeder.com
- initial package of upstream release 0.12.0 (Python Singlespec)
